import generate_settings
import generate_to_internal_settings_converter
import generate_to_settings_converter

#
# import _zivid.generate_camera_info
# import _zivid.generate_to_internal_camera_info_converter
# import _zivid.generate_to_camera_info_converter
#
import generate_settings_2d
import generate_to_internal_settings_2d_converter
import generate_to_settings_2d_converter

#
# import _zivid.generate_frame_info
# import _zivid.generate_to_frame_info_converter
# import _zivid.generate_to_frame_internal_info_converter
#
# import _zivid.generate_camera_state
# import _zivid.generate_to_camera_state_converter
# import _zivid.generate_to_internal_camera_state_converter
#
# import _zivid.generate_suggest_settings_parameters
# import _zivid.generate_to_internal_suggest_settings_parameters_converter
# import _zivid.generate_to_suggest_settings_parameters_converter


def generate():
    pass
    # generate_settings.start_traverse()
    # generate_to_settings_converter.start_traverse()
    # generate_to_internal_settings_converter.start_traverse()

    # _zivid.generate_camera_info.start_traverse()
    # _zivid.generate_to_camera_info_converter.start_traverse()
    # _zivid.generate_to_internal_camera_info_converter.start_traverse()

    # _zivid.generate_frame_info.start_traverse()
    # _zivid.generate_to_frame_info_converter.start_traverse()
    # _zivid.generate_to_frame_internal_info_converter.start_traverse()

    # _zivid.generate_camera_state.start_traverse()
    # _zivid.generate_to_camera_state_converter.start_traverse()
    # _zivid.generate_to_internal_camera_state_converter.start_traverse()

    # generate_settings_2d.start_traverse()
    # generate_to_settings_2d_converter.start_traverse()
    generate_to_internal_settings_2d_converter.start_traverse()

    # needs redoing
    # _zivid.generate_suggest_settings_parameters.start_traverse()
    # _zivid.generate_to_suggest_settings_parameters_converter.start_traverse()
    # _zivid.generate_to_internal_suggest_settings_parameters_converter.start_traverse()


generate()
